@@ -25,7 +25,8 @@ Execution <- list(execId=        "",
                   evRule=        "",
                   evMultiplier=  0,
                   modelCode=     "",
-                  lastLiquidity= 0L)
+                  lastLiquidity= 0L,
+                  pendingPriceRevision= FALSE)
 
 ExecutionFilter <- list(clientId= 0L,
                         acctCode= "",
@@ -114,7 +115,24 @@ ContractDetails <- list(contract=           Contract,
                         nextOptionDate=     "",
                         nextOptionType=     "",
                         nextOptionPartial=  FALSE,
-                        notes=              "")
+                        notes=              "",
+                        fundName=                        "",
+                        fundFamily=                      "",
+                        fundType=                        "",
+                        fundFrontLoad=                   "",
+                        fundBackLoad=                    "",
+                        fundBackLoadTimeInterval=        "",
+                        fundManagementFee=               "",
+                        fundClosed=                      FALSE,
+                        fundClosedForNewInvestors=       FALSE,
+                        fundClosedForNewMoney=           FALSE,
+                        fundNotifyAmount=                "",
+                        fundMinimumInitialPurchase=      "",
+                        fundSubsequentMinimumPurchase=   "",
+                        fundBlueSkyStates=               "",
+                        fundBlueSkyTerritories=          "",
+                        fundDistributionPolicyIndicator= "",
+                        fundAssetType=                   "")
 
 ContractDescription <- list(contract=           Contract,
                             derivativeSecTypes= character())
